pub fn max_align_of_generic_param<'tcx>(
tcx: TyCtxt<'tcx>,
caller: DefId,
ty: Ty<'tcx>,
) -> u64Expand description
Max align_of over all implementors of a generic type parameter’s trait
bounds (0 for non-param types or a parameter without a bounded set of
implementors).