resolve_callee_impl

Function resolve_callee_impl 

pub(crate) fn resolve_callee_impl<'tcx>(
    tcx: TyCtxt<'tcx>,
    caller_def_id: DefId,
    callee_def_id: DefId,
    callee_args: GenericArgsRef<'tcx>,
) -> Option<DefId>
Resolve a (possibly trait-method) callee to the concrete impl method that will actually be dispatched, given the caller context and the callee’s generic arguments. Returns None when the callee cannot be resolved to a distinct concrete item (e.g. still generic/virtual), or is not a trait method at all (callers should then keep the original DefId).